﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Windows.UI.Xaml;

namespace RadBulletGraph
{
    public abstract class ViewModelBase : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged( string propName )
        {
            PropertyChangedEventHandler eh = this.PropertyChanged;
            if ( eh != null )
            {
                eh( this, new PropertyChangedEventArgs( propName ) );
            }
        }
    }


    public class RandomViewModel : ViewModelBase
    {
        private DispatcherTimer timer;
        private Random r;

        private int callDuration;

        public int CallDuration
        {
            get { return callDuration; }
            set
            {
                callDuration = value;
                this.OnPropertyChanged( "CallDuration" );
            }
        }


        public RandomViewModel()
        {
            r = new Random();
            timer = new DispatcherTimer() { Interval = TimeSpan.FromSeconds( 1 ) };
            timer.Tick += timer_Tick;
            this.LoadData();
        }

        public void StopTimer()
        {
            this.timer.Stop();
        }

        public void StartTimer()
        {
            this.timer.Start();
        }

        void timer_Tick( object sender, object e )
        {
            this.UpdateIndicators();
        }

        private void LoadData()
        {
            UpdateIndicators();
        }

        private void UpdateIndicators()
        {
            this.CallDuration = r.Next( 0, 175 );
        }


    }

}
